@@ -117,7 +117,7 @@ vcov.tram <- function(object, with_baseline = FALSE, complete = FALSE, ...)
     ret <- solve(H)
     if (inherits(ret, "try-error"))
         return(vcov(as.mlt(object))[shift, shift])
-    if (any(diag(ret) < 0))
+    if (isTRUE(any(diag(ret) < 0))) ### there might be NAs
         return(vcov(as.mlt(object))[shift, shift])
     nm <- cf
     nm <- nm[!nm %in% names(object$fixed)]
@@ -508,11 +508,11 @@ perm_test.tram <- function(object, parm = names(coef(object)),
     alternative <- match.arg(alternative)
 
     parameter <- paste(switch(class(object)[1], 
-                                  "Colr" = "Log-odds ratio",
-                                   "Coxph" = "Log-hazard ratio",
-                                   "Lm" = "Standardised difference",
-                                   "Lehmann" = "Lehmann parameter",
-                                   "BoxCox" = "Standardised difference"))
+                              "Colr" = "Log-odds ratio",
+                              "Coxph" = "Log-hazard ratio",
+                              "Lm" = "Standardised difference",
+                              "Lehmann" = "Lehmann parameter",
+                              "BoxCox" = "Standardised difference"))
 
     block <- NULL
     if (!is.null(object$model$bases$interacting) && block_permutation) {
@@ -542,15 +542,20 @@ perm_test.tram <- function(object, parm = names(coef(object)),
 
         fx <- 0
         names(fx) <- parm
+        
+        ### <NOTE> misusing offset as nullvalue delta = mu won't work
+        ### because we would need to compute the permutation distribution always
+        ### for H0: delta = 0, not delta = mu
+        ### otherwise, permutation confidence intervals
+        ### are not aligned with permutation p-values
+        ### However, we can't just ignore the offset here
         off <- object$offset
+
         theta <- coef(as.mlt(object))
         theta <- theta[names(theta) != parm]
         w <- object$weights
         m0 <- mlt(object$model, data = object$data, weights = object$weights,
-                  offset = off, 
-                  ### NOTE with mlt 1.7-0, disable for the moment
-                  # scale = object$scale, 
-                  fixed = fx,
+                  offset = off, scaleparm = object$scaleparm, fixed = fx,
                   optim = object$optim, theta = theta)
 
         cf <- coef(m1)
@@ -576,7 +581,7 @@ perm_test.tram <- function(object, parm = names(coef(object)),
             rs <- resid(m1)
         }
         r0 <- (rs / w) * sqrt(vcov.tram(m1)[parm,parm])
-        ###                          ^^^^^^^^^ uses Schur complement
+        ###                   ^^^^^^^^^ uses Schur complement
         if (is.null(block)) {
             it0 <- coin::independence_test(r0 ~ Xf, teststat = "scalar", 
                 alternative = alternative, weights = ~ w, ...)
@@ -722,8 +727,7 @@ perm_test.tram <- function(object, parm = names(coef(object)),
         if (length(thetafix) > length(theta))
             fx <- thetafix[-names(theta)]
         m0 <- mlt(object$model, data = object$data, weights = object$weights,
-                  offset = off, # scale = object$scale, 
-                  fixed = fx,
+                  offset = off, scaleparm = object$scaleparm, fixed = fx,
                   optim = object$optim, theta = theta)
         
         if (length(list(...)) == 0) {
